@@ -1,7 +1,7 @@
 import logging
 import json
 
-from .utils.data import create_data
+from outliers.utils.data import create_data
 from .detectors.detection_models import DetectionModels
 from .detectors import pipelines
 from .definitions import MODEL_CONFIG_PATH
